pub trait FloatArray<T: ArrowFloatType + ?Sized>:
Array
+ Clone
+ 'static {
type FloatType: ArrowFloatType;
// Required methods
fn as_slice(&self) -> &[T::Native];
fn from_values(values: Vec<T::Native>) -> Self;
// Provided method
fn from_iter_values(values: impl IntoIterator<Item = T::Native>) -> Self
where Self: Sized { ... }
}Expand description
FloatArray is a trait that is implemented by all float type arrays
This is similar to arrow_array::PrimitiveArray but applies to all float types (including bfloat16)
and is implemented as a trait and not a struct
Required Associated Types
Required Methods
Sourcefn from_values(values: Vec<T::Native>) -> Self
fn from_values(values: Vec<T::Native>) -> Self
Construct an array from a vector of values.
Provided Methods
Sourcefn from_iter_values(values: impl IntoIterator<Item = T::Native>) -> Selfwhere
Self: Sized,
fn from_iter_values(values: impl IntoIterator<Item = T::Native>) -> Selfwhere
Self: Sized,
Construct an array from an iterator of values.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".