pub trait FloatToArrayType:
Float
+ Bounded
+ Sum
+ AddAssign<Self>
+ AsPrimitive<f64>
+ AsPrimitive<f32>
+ DivAssign
+ Send
+ Sync
+ Copy {
type ArrowType: ArrowFloatType<Native = Self>;
}Expand description
Trait to be implemented by native types that have a corresponding ArrowFloatType
implementation.
This helps define what operations are supported by native floats and also helps convert from a native type back to the corresponding Arrow float type.
Required Associated Types
Sourcetype ArrowType: ArrowFloatType<Native = Self>
type ArrowType: ArrowFloatType<Native = Self>
The corresponding ArrowFloatType implementation for this native type
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".