read_ipc_stream

Function read_ipc_stream 

pub fn read_ipc_stream(data: &Bytes) -> Result<Vec<RecordBatch>, ArrowError>
Read all RecordBatches from one Arrow IPC stream.

Zero-copy: each batch’s array data buffers are borrowed from the input message buffer(s) and not copied during decoding.

Uses FileDecoder directly (rather than StreamDecoder) to avoid a known edge case where StreamDecoder does not produce a batch for messages with a zero-length body when the message exactly fills the decode buffer.